@@ -23,7 +23,7 @@
 #![no_std]
 #![doc(
     test(attr(deny(warnings))),
-    html_root_url = "https://docs.rs/vek/0.15.3",
+    html_root_url = "https://docs.rs/vek/0.15.4",
     //html_logo_url = "https://yoanlcq.github.io/vek/logo.png",
     //html_favicon_url = "https://yoanlcq.github.io/vek/favicon.ico",
 )]
@@ -54,6 +54,9 @@ pub extern crate serde;
 #[cfg(feature = "mint")]
 pub extern crate mint;
 
+#[cfg(feature = "bytemuck")]
+pub extern crate bytemuck;
+
 pub extern crate num_integer;
 pub extern crate num_traits;
 
